<?php

namespace App\Http\Controllers;

use App\Models\Coupons;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class CouponsController extends Controller
{
    public function index()
    {
        $coupons = Coupons::all();

        return view('system.coupons.index', compact('coupons'));
    }

    public function create()
    {
        return view('system.coupons.add');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'promocode' => 'required',
            'points' => 'required',
            'ar_name' => 'required',
            'en_name' => 'required',
            'image' => 'required',
            'percentage' => 'required',
            'active' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Coupons::create($request->all());
        session()->flash('Add', 'تم اضافة الكوبون');

        return redirect()->route('coupons.index')->with('success', 'Coupon created successfully.');
    }

    public function show($id)
    {
        $coupon = Coupons::findOrFail($id);

        return view('system.coupons.show', compact('coupon'));
    }

    public function edit($id)
    {
        $coupon = Coupons::findOrFail($id);

        return view('system.coupons.edit', compact('coupon'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'promocode' => 'required',
            'points' => 'required',
            'ar_name' => 'required',
            'en_name' => 'required',
            'image' => 'required',
            'percentage' => 'required',
            'active' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Coupons::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل الكوبون');

        return redirect()->route('coupons.index')->with('success', 'Coupon updated successfully.');
    }

    public function destroy($id)
    {
        Coupons::findOrFail($id)->delete();
        session()->flash('delete', 'تم حذف الكوبون');

        return redirect()->route('coupons.index')->with('success', 'Coupon deleted successfully.');
    }
}
