<?php

namespace App\Http\Controllers;

use App\Models\Payments;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class PaymentsController extends Controller
{
    public function index()
    {
        $payments = Payments::all();

        return view('payments.index', compact('payments'));
    }

    public function create()
    {
        return view('payments.create');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'reservation_id' => 'required',
            'user_id' => 'required',
            'amount' => 'required',
            'type' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Payments::create($request->all());

        return redirect()->route('payments.index')->with('success', 'Payment created successfully.');
    }

    public function show($id)
    {
        $payment = Payments::findOrFail($id);

        return view('payments.show', compact('payment'));
    }

    public function edit($id)
    {
        $payment = Payments::findOrFail($id);

        return view('payments.edit', compact('payment'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'reservation_id' => 'required',
            'user_id' => 'required',
            'amount' => 'required',
            'type' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Payments::findOrFail($id)->update($request->all());

        return redirect()->route('payments.index')->with('success', 'Payment updated successfully.');
    }

    public function destroy($id)
    {
        Payments::findOrFail($id)->delete();

        return redirect()->route('payments.index')->with('success', 'Payment deleted successfully.');
    }}
