<?php

namespace App\Http\Controllers;

use App\Models\Program;
use App\Models\ProgramTypes;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramController extends Controller
{
    public function index()
    {
        $programs = Program::all();

        return view('system.programs.program', compact('programs'));
    }

    public function create()
    {
        $types = ProgramTypes::all();

        return view('system.programs.add_program',compact('types'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'type_id' => 'required',
            'program_name' => 'required',
            // 'rate' => 'required',
            // 'visitors' => 'required',
            'description' => 'required',
            'image' => 'required',
            'town' => 'required',
            'reservation_price' => 'required',
            'payment_duration' => 'required',
            'available_from' => 'required',
            'available_to' => 'required',
            'offer_price' => 'required',
            'offer_start_date' => 'required',
            'offer_end_date' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Program::create($request->all());
        session()->flash('Add', 'تم اضافة البرنامج');
        return redirect()->route('programs.index')->with('success', 'Program created successfully.');
    }

    public function show($id)
    {
        $program = Program::findOrFail($id);

        return view('programs.show', compact('program'));
    }

    public function edit(Request $request ,$id)
    {
        $program = Program::findOrFail($id);
        $types = ProgramTypes::all();
        return view('system.programs.edit', compact('program','types'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'type_id' => 'required',
            'program_name' => 'required',
            // 'rate' => 'required',
            // 'visitors' => 'required',
            'description' => 'required',
            'image' => 'required',
            'town' => 'required',
            'reservation_price' => 'required',
            'payment_duration' => 'required',
            'available_from' => 'required',
            'available_to' => 'required',
            'offer_price' => 'required',
            'offer_start_date' => 'required',
            'offer_end_date' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Program::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل البرنامج');

        return redirect()->route('programs.index')->with('success', 'Program updated successfully.');
    }

    public function destroy($id)
    {
        Program::findOrFail($id)->delete();
        session()->flash('delete', 'تم حذف البرنامج');

        return redirect()->route('programs.index')->with('success', 'Program deleted successfully.');
    }}
