<?php

namespace App\Http\Controllers;

use App\Models\ProgramExperiences;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramExperiencesController extends Controller
{
    public function index()
    {
        $programExperiences = ProgramExperiences::all();

        return view('program_experiences.index', compact('programExperiences'));
    }

    public function create()
    {
        return view('program_experiences.create');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'media_type' => 'required',
            'path' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        ProgramExperiences::create($request->all());

        return redirect()->route('program_experiences.index')->with('success', 'Program experience created successfully.');
    }

    public function show($id)
    {
        $programExperience = ProgramExperiences::findOrFail($id);

        return view('program_experiences.show', compact('programExperience'));
    }

    public function edit($id)
    {
        $programExperience = ProgramExperiences::findOrFail($id);

        return view('program_experiences.edit', compact('programExperience'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'media_type' => 'required',
            'path' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        ProgramExperiences::findOrFail($id)->update($request->all());

        return redirect()->route('program_experiences.index')->with('success', 'Program experience updated successfully.');
    }

    public function destroy($id)
    {
        ProgramExperiences::findOrFail($id)->delete();

        return redirect()->route('program_experiences.index')->with('success', 'Program experience deleted successfully.');
    }}
