<?php

namespace App\Http\Controllers;

use App\Models\ProgramTypes;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProgramTypesController extends Controller
{
    public function index()
    {
        $programTypes = ProgramTypes::all();

        return view('system.programTypes.types', compact('programTypes'));
    }

    public function create()
    {
        return view('system.programTypes.add');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'type' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        ProgramTypes::create($request->all());
        session()->flash('add', 'تم اضافه النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type created successfully.');
    }

    public function show($id)
    {
        $programType = ProgramTypes::findOrFail($id);

        return view('program_types.show', compact('programType'));
    }

    public function edit($id)
    {
        $programType = ProgramTypes::findOrFail($id);

        return view('system.programTypes.edit', compact('programType'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'type' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        ProgramTypes::findOrFail($id)->update($request->all());
        session()->flash('edit', 'تم تعديل النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type updated successfully.');
    }

    public function destroy($id)
    {
        ProgramTypes::findOrFail($id)->delete();
        session()->flash('delete', 'تم حذف النوع');

        return redirect()->route('programTypes.index')->with('success', 'Program type deleted successfully.');
    }}
