<?php

namespace App\Http\Controllers;

use App\Models\Rating;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class RatingController extends Controller
{
    public function index()
    {
        $ratings = Rating::all();

        return view('ratings.index', compact('ratings'));
    }

    public function create()
    {
        return view('ratings.create');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'user_id' => 'required',
            'rate' => 'required',
            'comment' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Rating::create($request->all());

        return redirect()->route('ratings.index')->with('success', 'Rating created successfully.');
    }

    public function show($id)
    {
        $rating = Rating::findOrFail($id);

        return view('ratings.show', compact('rating'));
    }

    public function edit($id)
    {
        $rating = Rating::findOrFail($id);

        return view('ratings.edit', compact('rating'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'program_id' => 'required',
            'user_id' => 'required',
            'rate' => 'required',
            'comment' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        Rating::findOrFail($id)->update($request->all());

        return redirect()->route('ratings.index')->with('success', 'Rating updated successfully.');
    }

    public function destroy($id)
    {
        Rating::findOrFail($id)->delete();

        return redirect()->route('ratings.index')->with('success', 'Rating deleted successfully.');
    }}
